@@ -6,9 +6,7 @@
 namespace kmeans {
 
 template<typename Input_>
-std::remove_cv_t<std::remove_reference_t<Input_> > I(Input_ x) {
-    return x;
-}
+using I = typename std::remove_cv<typename std::remove_reference<Input_>::type>::type;
 
 }
 
